@@ -18,6 +18,7 @@ import PyFin.tests.Analysis as Analysis
 import PyFin.tests.DateUtilities as DateUtilities
 import PyFin.tests.Env as Env
 import PyFin.tests.Math as Math
+import PyFin.tests.POpt as POpt
 import PyFin.tests.PricingEngines as PricingEngines
 
 
@@ -61,6 +62,8 @@ def test():
     suite.addTests(tests)
     tests = unittest.TestLoader().loadTestsFromTestCase(Math.Timeseries.TestTimeseries)
     suite.addTests(tests)
+    tests = unittest.TestLoader().loadTestsFromTestCase(POpt.TestOptimizer)
+    suite.addTests(tests)
 
     res = unittest.TextTestRunner(verbosity=3).run(suite)
     if len(res.errors) >= 1 or len(res.failures) >= 1:
